Module cli

Module cli 

Structs

Cli

Enums

Command
StrategyOption
Merge strategy option for resolving conflicting regions during vendor merges. These mirror the -X / --strategy-option values accepted by git merge.

Functions

name_from_url
Derive a vendor name from a URL by taking the last path component and stripping a trailing .git suffix, if present.