pub enum MergeOutcome {
UpToDate {
vendor: VendorSource,
},
Clean {
vendor: VendorSource,
},
Conflict {
index: Index,
vendor: VendorSource,
},
}Expand description
Result of a single vendor merge.
Variants
UpToDate
The vendor’s base already matches the latest refs/vendor/$name.
Nothing was changed.
Fields

vendor: VendorSourceThe vendor source (unchanged).
Clean
The merge completed cleanly. All changes are staged in the index and written to the working tree, but no commit has been created.
Fields

vendor: VendorSourceThe vendor source with updated base.
Conflict
The merge has conflicts. Conflict markers have been written to the
working tree. The returned git2::Index contains the conflict
entries. The caller is responsible for presenting them to the user.
base has still been updated in .gitvendors.