pub struct VendorSource {
pub name: String,
pub url: String,
pub branch: Option<String>,
pub base: Option<String>,
pub patterns: Vec<String>,
}Expand description
All metadata required to retrieve necessary objects from a vendor.
Fields
name: StringThe unique identifier for this particular vendor.
url: Stringbranch: Option<String>The branch to track on the upstream remote.
If not specified, this defaults to HEAD.
base: Option<String>The most recent merge base. If not specified, it is assumed that no prior merge has taken place and conflicts must be resolved manually.
patterns: Vec<String>Glob pattern(s) selecting which upstream files to vendor.
Implementations
Sourceimpl VendorSource
impl VendorSource