VendorSource

Struct VendorSource 

pub struct VendorSource {
    pub name: String,
    pub url: String,
    pub branch: Option<String>,
    pub base: Option<String>,
    pub patterns: Vec<String>,
}
All metadata required to retrieve necessary objects from a vendor.

Fields

name: String

The unique identifier for this particular vendor.

url: Stringbranch: Option<String>

The branch to track on the upstream remote. If not specified, this defaults to HEAD.

base: Option<String>

The most recent merge base. If not specified, it is assumed that no prior merge has taken place and conflicts must be resolved manually.

patterns: Vec<String>

Glob pattern(s) selecting which upstream files to vendor.

Implementations

Source

impl VendorSource

pub fn to_config(&self, cfg: &mut Config) -> Result<(), Error>

pub fn from_config(cfg: &Config, name: &str) -> Result<Option<Self>, Error>

pub fn head_ref(&self) -> String

The ref holding the latest fetched upstream tip.

pub fn tracking_branch(&self) -> String

The ref to track.